@@ -1,7 +1,10 @@
+"""A property graphs library for importing and generating cypher in python"""
+__version__=(0,5,1)
+__author__='Alex Miłowski'
+__author_email__='alex@milowski.com'
+
 from .cypher import read_graph, graph_to_cypher, cypher_literal, cypher_for_item, cypher_for_node, cypher_for_edge_relation, NodeItem, EdgeRelationItem
 from .schema import SchemaParser, Schema, NodeDefinition, EdgeDefinition
 
 __all__ = ['read_graph', 'graph_to_cypher', 'cypher_literal', 'cypher_for_item', 'cypher_for_node', 'cypher_for_edge_relation', 'NodeItem', 'EdgeRelationItem'
            'SchemaParser','Schema','NodeDefinition','EdgeDefinition']
-
-__version__ = '0.4'
